searchData={"items":[{"type":"module","title":"Shmex","doc":"This module allows using data placed in POSIX shared memory on POSIX\ncompliant systems.\n\nDefines a struct representing the actual shared memory object. The struct\nshould not be modified, and should always be passed around as a whole - see\n`t:Shmex.t/0`","ref":"Shmex.html"},{"type":"function","title":"Shmex.empty/1","doc":"Creates a new, empty shared memory area with the given capacity","ref":"Shmex.html#empty/1"},{"type":"function","title":"Shmex.ensure_not_gc/1","doc":"Ensures that shared memory is not garbage collected at the point of executing\nthis function.\n\nUseful when passing shared memory to other OS process, to prevent it\nfrom being garbage collected until received and mapped by that process.","ref":"Shmex.html#ensure_not_gc/1"},{"type":"function","title":"Shmex.new/1","doc":"Creates a new shared memory area filled with the existing data.","ref":"Shmex.html#new/1"},{"type":"function","title":"Shmex.new/2","doc":"Creates a new shared memory area initialized with `data` and sets its capacity.\n\nThe actual capacity is the greater of passed capacity and data size","ref":"Shmex.html#new/2"},{"type":"function","title":"Shmex.set_capacity/2","doc":"Sets the capacity of shared memory area.\n\nIf the capacity is smaller than the current size, data will be discarded and size modified","ref":"Shmex.html#set_capacity/2"},{"type":"function","title":"Shmex.to_binary/1","doc":"Returns shared memory contents as a binary.","ref":"Shmex.html#to_binary/1"},{"type":"type","title":"Shmex.t/0","doc":"Struct describing data kept in shared memory. Should not be modified\nand should always be passed around as a whole\n\n...including passing to the native code - there are functions in `:shmex_lib`\n(a native library exported via Bundlex) that will allow to transform Elixir\nstruct into a C struct and then access the shared memory from the native code.)\n\nShared memory should be available as long as the associated struct is not\ngarbage collected.","ref":"Shmex.html#t:t/0"},{"type":"module","title":"Shmex.Native","doc":"This module provides natively implemented functions allowing low-level\noperations on Posix shared memory. Use with caution!","ref":"Shmex.Native.html"},{"type":"function","title":"Shmex.Native.add_guard/1","doc":"Creates guard for existing shared memory.\n\nThis function should be only used when `Shmex` struct was created by\nsome other NIF and even though the SHM exists, it's guard field is set to `nil`.\nTrying to use it with SHM obtained via `allocate/1` will result in error.\n\nSee also docs for `allocate/1`","ref":"Shmex.Native.html#add_guard/1"},{"type":"function","title":"Shmex.Native.allocate/1","doc":"Creates shared memory segment and adds a guard for it.\n\nThe guard associated with this memory segment is placed in returned\n`Shmex` struct. When the guard resource is deallocated by BEAM,\nthe shared memory is unlinked and will disappear from the system when last process\nusing it unmaps it","ref":"Shmex.Native.html#allocate/1"},{"type":"function","title":"Shmex.Native.append/2","doc":"Concatenates two shared memory areas by appending the data from the second\nat the end of the first one. Fails with `{:error, {:einval, :ftruncate}}` if\nOS does not support changing shared memory capacity.\n\nThe first shared memory is a target that will contain data from both shared memory areas.\nIts capacity will be set to the sum of sizes of both shared memory areas.\nThe second one, the source, will remain unmodified.","ref":"Shmex.Native.html#append/2"},{"type":"function","title":"Shmex.Native.ensure_not_gc/1","doc":"Ensures that shared memory is not garbage collected at the point of executing\nthis function.\n\nUseful when passing shared memory to other OS process, to prevent it\nfrom being garbage collected until received and mapped by that process.","ref":"Shmex.Native.html#ensure_not_gc/1"},{"type":"function","title":"Shmex.Native.read/1","doc":"Reads the contents of shared memory and returns it as a binary.","ref":"Shmex.Native.html#read/1"},{"type":"function","title":"Shmex.Native.read/2","doc":"Reads `cnt` bytes from the shared memory and returns it as a binary.\n\n`cnt` should not be greater than `shm.size`","ref":"Shmex.Native.html#read/2"},{"type":"function","title":"Shmex.Native.set_capacity/2","doc":"Sets the capacity of shared memory area and updates the Shmex struct accordingly.","ref":"Shmex.Native.html#set_capacity/2"},{"type":"function","title":"Shmex.Native.split_at/2","doc":"Splits the contents of shared memory area into two by moving the data past\nthe specified position into a new shared memory.\n\n`shm` has to be an existing shared memory (obtained via `allocate/1`).\n\nIt virtually trims the existing shared memory to `position` bytes\nby setting `size` to `position` (The actual data is still present)\nand the overlapping data is copied into the new shared memory area.","ref":"Shmex.Native.html#split_at/2"},{"type":"function","title":"Shmex.Native.trim/1","doc":"Trims shared memory capacity to match its size.","ref":"Shmex.Native.html#trim/1"},{"type":"function","title":"Shmex.Native.trim/2","doc":"Drops `bytes` bytes from the beginning of shared memory area and\ntrims it to match the new size.","ref":"Shmex.Native.html#trim/2"},{"type":"function","title":"Shmex.Native.write/2","doc":"Writes the binary into the shared memory.\n\nOverwrites the existing content. Increases the capacity of shared memory\nto fit the data.","ref":"Shmex.Native.html#write/2"},{"type":"extras","title":"Shmex","doc":"# Shmex\n\n[![Hex.pm](https://img.shields.io/hexpm/v/shmex.svg)](https://hex.pm/packages/shmex)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/shmex/)\n[![CircleCI](https://circleci.com/gh/membraneframework/shmex.svg?style=svg)](https://circleci.com/gh/membraneframework/shmex)\n\nShmex is a library providing Elixir bindings for shared memory and native\nfunctions to manipulate it in NIFs.\n\nDocumentation is available at [HexDocs](https://hexdocs.pm/shmex)\n\nThe source code is available at [GitHub](https://github.com/membraneframework/shmex)","ref":"readme.html"},{"type":"extras","title":"Installation - Shmex","doc":"Add the following line to your `deps` in `mix.exs`. Run `mix deps.get`.\n\n```elixir\n\t{:shmex, \"~> 0.5.1\"}\n```\n\nAll native stuff is exported in `:lib` and `:shmex` [Bundlex](https://hex.pm/packages/bundlex) dependencies.\nTo import, add the following line to your nif specification in `bundlex.exs`\n```elixir\ndeps: [shmex: :lib]\n```\nand another one in your native header file\n```c\n#import  \n```","ref":"readme.html#installation"},{"type":"extras","title":"Testing - Shmex","doc":"To execute tests run `mix test`. These test tags are excluded by default:\n- `shm_tmpfs` - tests that require access to information about shared memory segments present in the OS via tmpfs, not supported e.g. by Mac OS\n- `shm_resizable` - tests for functions that involve resizing existing shared memory segments, not supported e.g. by Mac OS","ref":"readme.html#testing"},{"type":"extras","title":"Copyright and License - Shmex","doc":"Copyright 2018, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2018 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}